aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSimon Marchi <simon.marchi@efficios.com>2024-07-28 23:25:57 -0400
committerSimon Marchi <simon.marchi@efficios.com>2024-08-12 11:10:01 -0400
commit74e39223b5e7cb645720a81f2c6ec25f9f40998c (patch)
treee13012eaef0404681dee39c7faf52696cbc6c060
parentba96d2e697a35517c5ee6b6c20a2fe9a055f7e5f (diff)
downloadbinutils-74e39223b5e7cb645720a81f2c6ec25f9f40998c.zip
binutils-74e39223b5e7cb645720a81f2c6ec25f9f40998c.tar.gz
binutils-74e39223b5e7cb645720a81f2c6ec25f9f40998c.tar.bz2
gdb: pass inferior to target_current_description
Make the current inferior reference bubble up one level. Change-Id: I441f954877749dc5a861ab03e881b529dafc2efd
-rw-r--r--gdb/arch-utils.c4
-rw-r--r--gdb/target-descriptions.c10
-rw-r--r--gdb/target-descriptions.h7
3 files changed, 9 insertions, 12 deletions
diff --git a/gdb/arch-utils.c b/gdb/arch-utils.c
index 3247c36..9110f0e 100644
--- a/gdb/arch-utils.c
+++ b/gdb/arch-utils.c
@@ -595,7 +595,7 @@ gdbarch_update_p (struct gdbarch_info info)
/* Check for the current target description. */
if (info.target_desc == NULL)
- info.target_desc = target_current_description ();
+ info.target_desc = target_current_description (current_inferior ());
new_gdbarch = gdbarch_find_by_info (info);
@@ -654,7 +654,7 @@ set_gdbarch_from_file (bfd *abfd)
struct gdbarch *gdbarch;
info.abfd = abfd;
- info.target_desc = target_current_description ();
+ info.target_desc = target_current_description (current_inferior ());
gdbarch = gdbarch_find_by_info (info);
if (gdbarch == NULL)
diff --git a/gdb/target-descriptions.c b/gdb/target-descriptions.c
index 4f21044..23b5b10 100644
--- a/gdb/target-descriptions.c
+++ b/gdb/target-descriptions.c
@@ -541,14 +541,12 @@ target_clear_description (void)
internal_error (_("Could not remove target-supplied description"));
}
-/* Return the global current target description. This should only be
- used by gdbarch initialization code; most access should be through
- an existing gdbarch. */
+/* See target-descriptions.h. */
-const struct target_desc *
-target_current_description (void)
+const target_desc *
+target_current_description (inferior *inf)
{
- target_desc_info *tdesc_info = &current_inferior ()->tdesc_info;
+ target_desc_info *tdesc_info = &inf->tdesc_info;
if (tdesc_info->fetched)
return tdesc_info->tdesc;
diff --git a/gdb/target-descriptions.h b/gdb/target-descriptions.h
index 54c1f23..d708dbd 100644
--- a/gdb/target-descriptions.h
+++ b/gdb/target-descriptions.h
@@ -39,11 +39,10 @@ void target_find_description (void);
void target_clear_description (void);
-/* Return the current inferior's target description. This should only
- be used by gdbarch initialization code; most access should be
- through an existing gdbarch. */
+/* Return INF's target description. This should only be used by gdbarch
+ initialization code; most access should be through an existing gdbarch. */
-const struct target_desc *target_current_description (void);
+const target_desc *target_current_description (inferior *inf);
/* Record architecture-specific functions to call for pseudo-register
support. If tdesc_use_registers is called and gdbarch_num_pseudo_regs